==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/RectChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RectChangedEventArgsDescription } from "./RectChangedEventArgsDescription";
/**
 * @hidden
 */
export let RectChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RectChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RectChangedEventArgsDescriptionMetadata.a == null) {
                RectChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RectChangedEventArgsDescriptionMetadata.c(RectChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(RectChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(RectChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldRect", "Rect");
            a.item("NewRect", "Rect");
        }
        static d(a) {
            RectChangedEventArgsDescriptionMetadata.b(a);
            a.aa("RectChangedEventArgs", () => new RectChangedEventArgsDescription());
            a.z("RectChangedEventArgs", RectChangedEventArgsDescriptionMetadata.a);
        }
    }
    RectChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(RectChangedEventArgsDescriptionMetadata, 'RectChangedEventArgsDescriptionMetadata');
    RectChangedEventArgsDescriptionMetadata.a = null;
    return RectChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RectChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { RectChangedEventArgsDescription } from "./RectChangedEventArgsDescription";
/**
 * @hidden
 */
export let RectChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class RectChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (RectChangedEventArgsDescriptionMetadata.a == null) {
                RectChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RectChangedEventArgsDescriptionMetadata.c(RectChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(RectChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(RectChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldRect", "Rect");
            a.item("NewRect", "Rect");
        }
        static d(a) {
            RectChangedEventArgsDescriptionMetadata.b(a);
            a.ac("RectChangedEventArgs", () => new RectChangedEventArgsDescription());
            a.ab("RectChangedEventArgs", RectChangedEventArgsDescriptionMetadata.a);
        }
    }
    RectChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(RectChangedEventArgsDescriptionMetadata, 'RectChangedEventArgsDescriptionMetadata');
    RectChangedEventArgsDescriptionMetadata.a = null;
    return RectChangedEventArgsDescriptionMetadata;
})();
